@@ -187,7 +187,9 @@ class BundleFHIR:
     def add_object_to_entries(self, resource, response=None):
         entry = {}
         if type(resource) is dict and resource['resourceType'] == 'Patient':
-            entry['resource'] = PatientFHIR(patient_dict=resource)
+            patient = PatientFHIR()
+            patient.from_json(resource=json.dumps(resource))
+            entry['resource'] = patient
         elif type(resource) is dict and resource['resourceType'] == 'Bundle':
             entry['resource'] = BundleFHIR(resource=resource)
         elif type(resource) is dict and resource['resourceType'] == 'Immunization':
@@ -237,11 +239,11 @@ class BundleFHIR:
                     sub_entries = entry['resource'].get_entries(recurse=True, resource_type=resource_type)
                     for e in sub_entries:
                         entries.append(e)
-            return entries
         else:
             for entry in self.entries:
                 if resource_type is None or entry['resource'].resource_type == resource_type:
                     entries.append(entry['resource'])
+        return entries
 
 class ImmunizationFHIR:
     resource_type = 'Immunization'
